﻿using System;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows;

namespace RichTextBoxSubSuperscript
{
    public static class RichTextBoxHelpers
    {
        /// <summary>
        /// Toggle Superscript for the currently selected text in a RichTextBox. Does not require the font to be OpenType or have a Superscript font style.
        /// 
        /// Doesn't attempt to change/restore the size of the font, just moves the baseline.
        /// </summary>
        /// <param name="richTextBox">RichTextBox with selected text</param>
        public static void ToggleSelectionSuperscript(this RichTextBox richTextBox)
        {
            var currentAlignment = richTextBox.Selection.GetPropertyValue(Inline.BaselineAlignmentProperty);

            BaselineAlignment newAlignment = ((BaselineAlignment)currentAlignment == BaselineAlignment.Superscript) ? BaselineAlignment.Baseline : BaselineAlignment.Superscript;
            richTextBox.Selection.ApplyPropertyValue(Inline.BaselineAlignmentProperty, newAlignment);
        }

        /// <summary>
        /// Toggle Subscript for the currently selected text in a RichTextBox. Does not require the font to be OpenType or have a Subscript font style.
        /// 
        /// Doesn't attempt to change/restore the size of the font, just moves the baseline.
        /// </summary>
        /// <param name="richTextBox">RichTextBox with selected text</param>
        public static void ToggleSelectionSubscript(this RichTextBox richTextBox)
        {
            var currentAlignment = richTextBox.Selection.GetPropertyValue(Inline.BaselineAlignmentProperty);

            BaselineAlignment newAlignment = ((BaselineAlignment)currentAlignment == BaselineAlignment.Subscript) ? BaselineAlignment.Baseline : BaselineAlignment.Subscript;
            richTextBox.Selection.ApplyPropertyValue(Inline.BaselineAlignmentProperty, newAlignment);
        }
    }
}
